#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 integer-logarithms
version:              1.0.4
visibility:           public
id:                   integer-logarithms-1.0.4-6sqPSC4SrwaHo967rxF2W5
key:                  integer-logarithms-1.0.4-6sqPSC4SrwaHo967rxF2W5
license:              MIT
copyright:
    (c) 2011 Daniel Fischer, 2017-2020 Oleg Grenrus, Andrew Lelechenko

maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Daniel Fischer
stability:            Provisional
homepage:             https://github.com/haskellari/integer-logarithms
synopsis:             Integer logarithms.
description:
    "Math.NumberTheory.Logarithms" and "Math.NumberTheory.Powers.Integer"
    from the arithmoi package.

    Also provides "GHC.Integer.Logarithms.Compat" and
    "Math.NumberTheory.Power.Natural" modules, as well as some
    additional functions in migrated modules.

category:             Math, Algorithms, Number Theory
abi:                  ee3b4132cb629d6e1633dc6b5d9c74de
exposed:              True
exposed-modules:
    GHC.Integer.Logarithms.Compat Math.NumberTheory.Logarithms
    Math.NumberTheory.Powers.Integer Math.NumberTheory.Powers.Natural

import-dirs:          /usr/lib/ghc-9.6.6/site-local/integer-logarithms-1.0.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/integer-logarithms-1.0.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/integer-logarithms-1.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-integer-logarithms
hs-libraries:         HSinteger-logarithms-1.0.4-6sqPSC4SrwaHo967rxF2W5
depends:
    array-0.5.6.0 base-4.18.2.1 ghc-bignum-1.3 ghc-prim-0.10.0

haddock-interfaces:
    /usr/share/doc/haskell-integer-logarithms/html/integer-logarithms.haddock

haddock-html:         /usr/share/doc/haskell-integer-logarithms/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

